"""
The test suite for this demo project.

It is being run as part of the :ref:`book` test suite.  You can
manually run just this suite using::

  $ go adg
  $ python manage.py test


.. autosummary::
   :toctree:

   test_beid
   test_nullchar
   test_simple
   test_webindex
"""
