# -*- coding: UTF-8 -*-
# Copyright 2012-2014 Rumma & Ko Ltd
# License: BSD (see file COPYING for details)
"""Content Management à la Lino.

Lino CMS is an example about how content management might look like
with Lino.  It is not yet being used on any production environment.


"""
