# -*- coding: UTF-8 -*-
# Copyright 2014-2016 Rumma & Ko Ltd
# License: BSD (see file COPYING for details)

"""
This is the main module of the `estref` project.
This is like :ref:`belref`, but for Estonia instead of Belgium.
"""

