# Generated by Django 2.2.4 on 2019-08-09 10:40

from django.db import migrations, models
import django.db.models.deletion
import lino.core.choicelists
import lino.core.fields
import lino.modlib.printing.choicelists


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contacts', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='SiteConfig',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('default_build_method', lino.core.choicelists.ChoiceListField(blank=True, choicelist=lino.modlib.printing.choicelists.BuildMethods, choices=[(lino.modlib.printing.choicelists.LatexBuildMethod('latex'), 'LatexBuildMethod'), (lino.modlib.printing.choicelists.RtfBuildMethod('rtf'), 'RtfBuildMethod'), (lino.modlib.printing.choicelists.XmlBuildMethod('xml'), 'XmlBuildMethod')], help_text='The default build method to use when rendering printable documents.', max_length=50, null=True, verbose_name='Default build method')),
                ('simulate_today', models.DateField(blank=True, help_text='A constant user-defined date to be substituted as current\nsystem date.', null=True, verbose_name='Simulated date')),
                ('next_partner_id', models.IntegerField(blank=True, default=100, help_text='The next automatic id for any new partner.', null=True, verbose_name='Next partner id')),
                ('site_company', models.ForeignKey(blank=True, help_text='The organisation who runs this site.  This is used e.g. when\nprinting your address in certain documents or reports.  Or\nnewly created partners inherit the country of the site owner.', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='site_company_sites', to='contacts.Company', verbose_name='Site owner')),
            ],
            options={
                'verbose_name': 'Site configuration',
                'abstract': False,
            },
            bases=(models.Model, lino.core.fields.TableRow),
        ),
    ]
