# -*- coding: UTF-8 -*-
# Copyright 2016-2017 Rumma & Ko Ltd
# License: BSD (see file COPYING for details)
"""Fixtures specific for Lino Care.

.. autosummary::
   :toctree:

   models


"""

from lino_xl.lib.tickets import *
from lino.api import _


# class Plugin(Plugin):
#     verbose_name = _("Pleas")
#     extends_models = ['Ticket']
    
