"""This package contains example applications included with the Lino
book.  These can be used either out of the box or as a base for
derivated work.

See :doc:`/dev/projects` which explains how to try them.

Usage examples of real-world :term:`Lino applications <Lino application>`:


.. autosummary::
   :toctree:

   apc
   pierre
   cosi_ee
   team
   bs3
   public
   anna
   liina
   lydia
   avanti1

Examples used by a tutorial:

.. autosummary::
   :toctree:

   chooser
   min1
   mti
   nomti
   lets1
   lets2
   actors
   actions
   tables
   dumps
   combo
   polly
   polls
   polls2
   watch
   watch2
   workflows


Poorly documented examples at different development states:

.. autosummary::
   :toctree:

   min2
   chatter
   max
   cms
   belref
   estref


Technical

.. autosummary::
   :toctree:

   docs

Sleeping:

.. autosummary::
   :toctree:

   events
   crl
   homeworkschool
   igen
   i18n

"""
