from lino.projects.std.settings import *


SITE = Site(globals(), 'lino_book.projects.20100212')

# INSTALLED_APPS = (
#     'lino',
#     'lino_book.projects.20100212',  # Explaining Django ticket 12801
# )

#~ LOGGING = dict(filename='system.log',level='DEBUG',mode='w')
