# -*- coding: UTF-8 -*-
# Copyright 2015-2017 Rumma & Ko Ltd
# License: BSD (see file COPYING for details)
"""A :ref:`care` site with languages "en fr de".

.. autosummary::
   :toctree:

   lib
   user_types
   settings

"""

