# -*- coding: UTF-8 -*-
# Copyright 2014-2017 Rumma & Ko Ltd
# License: BSD (see file COPYING for details)
"""

.. autosummary::
   :toctree:

   demo
   doctests
   www
   memory



"""

from __future__ import print_function
from __future__ import unicode_literals

# from lino_book.projects.team.settings import *
from lino_care.lib.care.settings import *
from lino.api.ad import _

