# -*- coding: UTF-8 -*-
# Copyright 2013-2016 Rumma & Ko Ltd
# License: BSD (see file COPYING for details)
"""
The Lino Voga variant named "Roger".

.. autosummary::
   :toctree:

    lib
    settings
    settings.fixtures.voga
    tests.test_faggio
    tests.test_webindex
    tests.test_max_places

"""

