# -*- coding: UTF-8 -*-


__copyright__ = """\
Copyright (c) 2012-2013 Rumma & Ko Ltd.
This software comes with ABSOLUTELY NO WARRANTY and is
distributed under the terms of the GNU Lesser General Public License.
See file COPYING.txt for more information."""
