# -*- coding: UTF-8 -*-
# Copyright 2015-2018 Rumma & Ko Ltd
# License: BSD (see file COPYING for details)
"""
A readonly user interface to :mod:`team
<lino_book.projects.team>`.

See :ref:`noi.specs.bs3`.

.. autosummary::
   :toctree:

   settings
   tests
"""

