# -*- coding: UTF-8 -*-
# Copyright 2015-2017 Rumma & Ko Ltd
# License: BSD (see file COPYING for details)
"""Shows :ref:`noi` as a ticket management system for software
developer teams.

.. autosummary::
   :toctree:

   settings
   tests
  

.. module:: lino_book.projects.team.urls

Adds customized urlpatters when use_restful is True.

.. data:: urlpatterns

    Blabla.

"""

